@@ -7,7 +7,7 @@
  * MSVCRT.DLL, or MSVCRn.DLL which does.
  *
  *
- * $Id: wctob.c,v 3346bd5e5239 2020/07/04 21:06:58 keith $
+ * $Id: wctob.c,v 28b17d1c4eab 2020/07/07 21:02:51 keith $
  *
  * Written by Keith Marshall <keith@users.osdn.me>
  * Copyright (C) 2020, MinGW.org Project
@@ -51,11 +51,4 @@ int wctob( wint_t wc )
     ? (int)(retval.u) : EOF;
 }
 
-/* FIXME: these aliases are provided for link-compatibitity with
- * libraries compiled against mingwrt-5.3.x; they may be removed
- * from future versions of mingwrt.
- */
-int __msvcrt_wctob( wint_t )__attribute__((__weak__,__alias__("wctob")));
-int __mingw_wctob( wint_t )__attribute__((__weak__,__alias__("wctob")));
-
 /* $RCSfile: wctob.c,v $: end of file */
